
require 'socket'

class Wideact::Client
	def initialize(name, args = { host: "localhost", port: 40444, server: nil })
		@host = args[:host]
		@port = args[:port]
		if args[:server].nil?
			@client_socket = TCPSocket.new @host, @port
		else
			@client_socket = args[:server]
		end

		@listeners = []

		@from_server = Thread.new {
			loop do
				while data = @client_socket.gets
					if data.start_with?("MESSAGE")
						parse(data)
					end
				end
			end
		}

		@from_server.run

		connect(name)
	end

	def parse(data)
		message = data.split(" ", 3)

		return if message.length < 3

		@listeners.each do |listener|
			listener.call(message[1], message[2])
		end
	end

	def connect(name)
		@client_socket.puts "CONNECT #{name}"
	end

	def message(receiver, message)
		@client_socket.puts "MESSAGE #{receiver} #{message}"
	end

	def add_listener(&listener)
		@listeners.push(listener)
	end

	def close
		@from_server.stop
		@client_socket.close
	end
end

